Documentation
¶
Index ¶
- Constants
- Variables
- func AggregateIntoLines(parts []string, maxWidth int) ([]string, error)
- func Help(options ...Options) kong.Option
- func NewPrettyPrinter(printOpts Options) kong.HelpPrinter
- func PrettyValueFormatter(formatter kong.HelpValueFormatter) kong.HelpValueFormatter
- func TruncateWithSuffix(line string, width int, suffix string) string
- func Visible(str string) string
- func VisibleLen(str string) int
- type Options
Constants ¶
const DefaultWidth = 80
DefaultWidth is the fallback width if it can not be automatically determined.
Variables ¶
var ColorCommand = color.New(color.FgCyan).SprintFunc()
var ColorDefault = color.New(color.FgMagenta).SprintFunc()
var ColorExample = color.New(color.FgYellow).SprintFunc()
TODO: Make these configurable
var ColorLow = color.HiBlackString
var ColorPlaceHolder = ColorDefault
var ColorRequired = color.New(color.FgRed).SprintFunc()
var ColorType = ColorExample
Functions ¶
func NewPrettyPrinter ¶ added in v0.2.0
func NewPrettyPrinter(printOpts Options) kong.HelpPrinter
func PrettyValueFormatter ¶
func PrettyValueFormatter(formatter kong.HelpValueFormatter) kong.HelpValueFormatter
func TruncateWithSuffix ¶ added in v0.2.0
func VisibleLen ¶
Calculates the length of a string only counting visible characters
Types ¶
Click to show internal directories.
Click to hide internal directories.